summaryrefslogtreecommitdiffstats
path: root/pkgs/top-level/all-packages.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/top-level/all-packages.nix')
-rw-r--r--pkgs/top-level/all-packages.nix14
1 files changed, 13 insertions, 1 deletions
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index 28f7e07f2be4..532f0eb6ca99 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -1,4 +1,4 @@
/* This file composes the Nix Packages collection. That is, it
imports the functions that build the various packages, and calls
them with appropriate arguments. The result is a set of all the
packages in the Nix Packages collection for some particular
@@ -3597,6 +3597,13 @@ let
libart = gnome.libart_lgpl;
};
+ goffice_0_9 = callPackage ../development/libraries/goffice/0.9.nix {
+ inherit (gnome) libglade libgnomeui;
+ gconf = gnome.GConf;
+ libart = gnome.libart_lgpl;
+ gtk = gtk3;
+ };
+
goocanvas = callPackage ../development/libraries/goocanvas { };
google_perftools = callPackage ../development/libraries/google-perftools { };
@@ -6795,6 +6802,11 @@ let
inherit (gnome) GConf;
};
+ gnumeric = callPackage ../applications/office/gnumeric {
+ goffice = goffice_0_9;
+ inherit (gnome) libglade scrollkeeper;
+ };
+
gnunet08 = callPackage ../applications/networking/p2p/gnunet/0.8.nix {
inherit (gnome) libglade;
guile = guile_1_8;
@@ -1,4 +1,4 @@
-/* This file composes the Nix Packages collection. That is, it
+/* This file composes the Nix Packages collection. That is, it gtk3
imports the functions that build the various packages, and calls
them with appropriate arguments. The result is a set of all the